@@ -41,7 +41,7 @@ class LocalLoader(Loader):
             if self.__stats:
                 bytes = helpers.BytesStatsWrapper(bytes, self.__stats)
         except IOError as exception:
-            raise exceptions.IOError(str(exception))
+            raise exceptions.LoadingError(str(exception))
 
         # Return bytes
         if mode == 'b':
